@@ -1,6 +1,6 @@
-REM  $Header: /Users/claude/fuzz/lib/Genezzo/RCS/dict.sql,v 1.7 2006/01/26 08:53:50 claude Exp claude $
+REM  $Header: /Users/claude/fuzz/lib/Genezzo/RCS/dict.sql,v 1.8 2006/03/30 07:21:49 claude Exp claude $
 REM
-REM $Revision: 1.7 $
+REM $Revision: 1.8 $
 REM
 REM copyright (c) 2005, 2006 Jeffrey I Cohen, all rights reserved, worldwide
 REM
@@ -19,5 +19,8 @@ REM i  dict_test_1 a 1 b 2 c 3 ;
 
 alter table _tspace add constraint tspace_tsname_uk unique (tsname);
 
+create table dual (dummy varchar(1));
+insert into dual values ('X');
+
 REM always commit changes!!
 commit ;
